@@ -361,9 +361,17 @@ def restore_backup(request):
     node = nodes[0]
     nodes = node.xpath('//b:config', namespaces=namespaces)
     
+    # we also have to set default config values
+    from pyrone.models.setup.config import setup as config_setup
+    config_setup(dbsession)
+        
     for node in nodes:
-        c = Config(node.get('id'), node.text)
-        dbsession.add(c)
+        c = dbsession.query(Config).get(node.get('id'))
+        if c is None:
+            c = Config(node.get('id'), node.text)
+            dbsession.add(c)
+        else:
+            c.value = node.text
         
     # now restore users
     nodes = xmldoc.xpath('//b:backup/b:users', namespaces=namespaces)
@@ -757,3 +765,23 @@ def delete_accounts_ajax(request):
     transaction.commit()
     
     return c
+
+@view_config(route_name='admin_settings_widget_pages', renderer='/admin/settings_widget_pages.mako', permission='admin', request_method='GET')
+def view_pages_widget_settings(request):
+    c = dict(errors=dict(), settings=dict())
+    
+    widget_pages_pages_spec = config.get('widget_pages_pages_spec')
+    
+    c['settings']['widget_pages_pages_spec'] = widget_pages_pages_spec;
+    
+    return c
+
+@view_config(route_name='admin_settings_widget_pages_save_ajax', renderer='json', permission='admin', request_method='POST')
+def save_pages_widget_settings_ajax(request):
+    c = dict()
+    
+    widget_pages_pages_spec = request.POST['widget_pages_pages_spec']
+    log.debug(widget_pages_pages_spec)
+    config.set('widget_pages_pages_spec', widget_pages_pages_spec)
+    config.clear_cache()
+    return c
\ No newline at end of file
