@@ -8,6 +8,7 @@ import os
 from PIL import Image
 from sqlalchemy.orm import eagerload
 from time import time
+from webhelpers.feedgenerator import Rss201rev2Feed
 
 from pyramid.response import Response
 from pyramid.i18n import TranslationString as _
@@ -594,6 +595,7 @@ def add_article_comment_ajax(request):
 def approve_article_comment_ajax(request):
     comment_id = int(request.matchdict['comment_id'])
     dbsession = DBSession()
+    transaction.begin()
     comment = dbsession.query(Comment).get(comment_id)
     if comment is None:
         return HTTPNotFound()
@@ -605,7 +607,6 @@ def approve_article_comment_ajax(request):
         return HTTPNotFound()
 
     orig = comment.is_approved
-    transaction.begin()
     comment.is_approved = True
 
     if not orig:
@@ -804,3 +805,57 @@ def download_file_preview(request):
     response.headerlist += headers
     
     return response
+
+@view_config(route_name='blog_latest_rss')
+def latest_rss(request):
+    """
+    Create rss feed with the latest published articles and return them as the atom feed
+    """
+    dbsession= DBSession()
+    
+    q = dbsession.query(Article).options(eagerload('tags')).options(eagerload('user')).filter(Article.is_draft==False).order_by(Article.updated.desc())
+    articles = q[0:10]
+    rss_title = get_config('site_title') + ' - ' + _('Latest articles feed')
+    site_base_url = get_config('site_base_url')
+    feed = Rss201rev2Feed(
+        title=rss_title, 
+        link=site_base_url,
+        description='',
+        language='en')
+    
+    for a in articles:
+        link = h.article_url(request, a)
+        tags_list = []
+        for t in a.tags:
+            tags_list.append(t.tag)
+        feed.add_item(title=a.title, link=link, description=a.rendered_preview, pubdate=h.timestamp_to_dt(a.published),
+            unique_id=str(a.id), categories=tags_list)
+        
+    response = Response(body=feed.writeString('utf-8'), content_type='application/rss+xml')
+    return response
+
+@view_config(route_name='blog_view_moderation_queue', renderer='/blog/comments-moderation.mako', permission='admin')
+def view_moderation_queue(request):
+    c = dict(comments=list())
+    
+    dbsession = DBSession()
+    comments = dbsession.query(Comment).filter(Comment.is_approved==False).all()
+    
+    for x in comments:
+        # set real email
+        if x.user is not None:
+            x._real_email = x.user.email
+        else:
+            x._real_email = x.email
+        if x._real_email == '':
+            x._real_email = None
+        
+        # truncate comment text
+        trunc_pos = 200
+        x._truncated_body = None
+        if len(x.rendered_body) > trunc_pos:
+            x._truncated_body = x.rendered_body[0:trunc_pos]
+            
+        c['comments'].append(x)
+    
+    return c
\ No newline at end of file
